'
'       foldercopyx.vbs         2020-11, 2021-01, 2021-05
'
'       Copy chosen folders (arguments) to a selectable target folder,
'       using the Shell method BrowseForFolder and the Robocopy program.
'       The intended usage is to copy only modified folders and files.
'

Dim args, folder, fspec, msg, n, quote, targetroot
Dim srcFolder, srcFile, destFolder
Dim copycmd, copyoptions, opt1, opt2
Dim fso     ' shared object variable

msg = "Determine the target folder."

targetroot = ""     ' one may set this to a desired target drive or folder

' copy program (note the trailing and leading spaces!)
copycmd = "robocopy "
opt1 = " /mir"
opt2 = " /xo /xj /dcopy:T /v /r:10 /w:2 /dst"

quote = Chr(34)

args = Wscript.Arguments.Count
If args = 0 Then WScript.Quit

folder = GetFolder(msg, targetroot, 0)
If Len(folder) = 0 Then WScript.Quit

Set fso = CreateObject("Scripting.FileSystemObject")

For n = 0 To args - 1
    fspec = Wscript.Arguments(n)
    With fso
        If IsFolder(fspec) Then
            srcFolder = fspec
            destFolder = .BuildPath(folder, .GetBaseName(fspec))
            srcFile = vbNullString  ' ""
            copyoptions = opt1 & opt2
        Else
            srcFolder = .GetParentFolderName(fspec)
            destFolder = folder
            srcFile = " " & quote & .GetFileName(fspec) & quote
            copyoptions = opt2
        End If
    End With
    srcFolder = quote & srcFolder & quote & " "
    destFolder = quote & destFolder & quote
    RunCopy srcFolder, destFolder, srcFile, copycmd, copyoptions
Next

WScript.Quit


Function GetFolder(ByVal sTitle, ByVal vRoot, ByVal fNoNew)

    Dim obj, flags

    If vRoot = "" Then vRoot = CInt(17)     ' ssfDRIVES
    flags = 1 + 64 + 256                    ' only FS dirs. + new UI style + hint display
    If fNoNew Then flags = flags + 512      ' no "New Folder" button in the browse dialog box
    GetFolder = ""

    Set obj = CreateObject("Shell.Application")
    If obj Is Nothing Then Exit Function
    Set obj = obj.BrowseForFolder(0, sTitle, flags, vRoot)
    If obj Is Nothing Then Exit Function
    Set obj = obj.Self
    If obj Is Nothing Then Exit Function
    GetFolder = CStr(obj.Path)
    Set obj = Nothing

End Function


Sub RunCopy(source, dest, file, cmd, switches)

    Dim cmdline, wsh

    On Error Resume Next
    Set wsh = WScript.CreateObject("WScript.Shell")
    cmdline = cmd & source & dest & file & switches

    wsh.Run cmdline, , vbTrue

    If Err Then Err.Clear
    On Error GoTo 0

End Sub


Function IsFolder(fspec)

    'Dim fso     ' shared object variable
    Dim f

    On Error Resume Next
    Set f = fso.GetFolder(fspec)
    If Err Then
        IsFolder = False
        Err.Clear
    Else
        IsFolder = True
    End If
    On Error GoTo 0

End Function


