'
'       foldercopyx2.vbs        2021-09
'
'       Copy chosen folders (arguments) to a selectable target folder,
'       using the Shell method BrowseForFolder and the RoboCopy program.
'       The prepared usage is for copying only modified folders and files.
'       This script version is derived from foldercopyx.vbs,
'       it runs as a console script and uses a different call method.
'

Dim args, folder, fspec, n, quote, targetroot
Dim srcFolder, srcFile, destFolder
Dim copycmd, copyoptions, opt1, opt2
Dim fso     ' shared object variable
Dim msg1, msg2, msg3, msg4, msg5    ' shared message variables

args = Wscript.Arguments.Count
If args = 0 Then WScript.Quit

If Not IsConsole Then Restart : WScript.Quit

DefineMsgs 0
' Procedure call for german messages / deutsche Texte:
'DefineMsgs 1

WScript.Echo msg1
WScript.Echo msg2 & args
WScript.Echo msg3

targetroot = ""     ' one may set this to a desired target drive or folder
' copy program (note the trailing and leading spaces!):
copycmd = "robocopy "
opt1 = " /mir"
opt2 = " /xo /xj /dcopy:T /v /r:10 /w:2 /dst"
quote = Chr(34)

folder = GetFolder(msg4, targetroot, 0)
If Len(folder) = 0 Then WScript.Quit

WScript.Echo msg5

Set fso = CreateObject("Scripting.FileSystemObject")

For n = 0 To args - 1
    fspec = Wscript.Arguments(n)
    With fso
        If IsFolder(fspec) Then
            srcFolder = fspec
            destFolder = .BuildPath(folder, .GetBaseName(fspec))
            srcFile = vbNullString
            copyoptions = opt1 & opt2
        Else
            srcFolder = .GetParentFolderName(fspec)
            destFolder = folder
            srcFile = " " & quote & .GetFileName(fspec) & quote
            copyoptions = opt2
        End If
    End With
    srcFolder = quote & srcFolder & quote & " "
    destFolder = quote & destFolder & quote
    RunCopy srcFolder, destFolder, srcFile, copycmd, copyoptions
Next

WScript.Quit


Sub DefineMsgs(flag)

    'Shared msg1, msg2, msg3, msg4, msg5    ' messages

    If flag Then
        msg1 = "FolderCopy Script - ausgewhlte Ordner und Dateien kopieren"
        msg2 = "Ausgewhlte Objekte: "
        msg3 = "Auswahl des Zielordners ..."
        msg4 = "Bestimmen Sie den Zielordner. Die ausgewhlten Objekte werden an diesen Ort kopiert."   ' Shell-Dialog
        msg5 = "Ausgewhlte Objekte werden nun kopiert ..."
    Else
        msg1 = "FolderCopy script - copying selected folders and files"
        msg2 = "Objects selected: "
        msg3 = "Choose the target folder ..."
        msg4 = "Determine the target folder. The selected objects will be copied to this location."     ' shell dialog
        msg5 = "Selected objects will be copied now ..."
    End If

End Sub


Function GetFolder(ByVal sTitle, ByVal vRoot, ByVal fNoNew)

    Dim obj, flags

    If vRoot = "" Then vRoot = CInt(17)     ' ssfDRIVES
    flags = 1 + 64 + 256                    ' only FS dirs. + new UI style + hint display
    If fNoNew Then flags = flags + 512      ' no "New Folder" button in the browse dialog box
    GetFolder = ""

    Set obj = CreateObject("Shell.Application")
    If obj Is Nothing Then Exit Function
    Set obj = obj.BrowseForFolder(0, sTitle, flags, vRoot)
    If obj Is Nothing Then Exit Function
    Set obj = obj.Self
    If obj Is Nothing Then Exit Function
    GetFolder = CStr(obj.Path)
    Set obj = Nothing

End Function


Sub RunCopy(source, dest, file, cmd, switches)

    Dim cmdline, wsh

    On Error Resume Next
    Set wsh = WScript.CreateObject("WScript.Shell")
    cmdline = cmd & source & dest & file & switches
    wsh.Exec cmdline

    If Err Then Err.Clear
    On Error GoTo 0

End Sub


Function IsFolder(fspec)

    'Shared fso     ' FSO object variable
    Dim f

    On Error Resume Next
    Set f = fso.GetFolder(fspec)
    If Err Then
        IsFolder = False
        Err.Clear
    Else
        IsFolder = True
    End If
    On Error GoTo 0

End Function


Function IsConsole
    IsConsole = (InStrRev(LCase(WScript.FullName),"cscript") <> 0)
End Function


Sub Restart
    Dim cmd, wsh
    cmd = "%SystemRoot%\System32\cscript.exe //nologo " & _
            WScript.ScriptFullName & GetArgumentsQuoted(Wscript.Arguments)
    Set wsh = WScript.CreateObject("WScript.Shell")
    wsh.Run cmd
    WScript.Quit
End Sub


Function GetArguments(args)
    Dim a
    For Each a In args
        GetArguments = GetArguments & " " & a
    Next
End Function

Function GetArgumentsQuoted(args)
    Dim a, q
    q = Chr(34)
    For Each a In args
        GetArgumentsQuoted = GetArgumentsQuoted & " " & q & a & q
    Next
End Function


