'
'       foldercopyxs.vbs        2020-11, 2021-01
'
'       Copy one chosen folder to a selectable target folder,
'       using the Shell method BrowseForFolder and the Robocopy program.
'       Program parameters will copy only modified folder contents.
'       This script version is derived from foldercopyx.vbs,
'       but offering the selection of a single source folder instead of
'       processing script arguments.
'

Dim msg1, msg2, quote, targetroot
Dim srcFolder, destFolder, copycmd, copyoptions

msg1 = "Choose the folder to copy (source)."
msg2 = "Determine the target folder."

targetroot = ""     ' one may set this to a desired target drive or folder

' copy program (note the trailing and leading spaces!)
copycmd = "robocopy "
copyoptions = " /mir /xo /xj /dcopy:T /v /r:10 /w:2 /dst"

srcFolder = GetFolder(msg1, "", True)
If Len(srcFolder) = 0 Then WScript.Quit

destFolder = GetFolder(msg2, targetroot, 0)
If Len(destFolder) = 0 Then WScript.Quit

destFolder = TargetName(destFolder, srcFolder)

quote = Chr(34)
srcFolder = quote & srcFolder & quote & " "
destFolder = quote & destFolder & quote

RunCopy srcFolder, destFolder, copycmd, copyoptions

WScript.Quit


Function GetFolder(ByVal sTitle, ByVal vRoot, ByVal fNoNew)

    Dim obj, flags

    If vRoot = "" Then vRoot = CInt(17)     ' ssfDRIVES
    flags = 1 + 64 + 256                    ' only FS dirs. + new UI style + hint display
    If fNoNew Then flags = flags + 512      ' no "New Folder" button in the browse dialog box

    GetFolder = ""
    Set obj = CreateObject("Shell.Application")
    If obj Is Nothing Then Exit Function
    Set obj = obj.BrowseForFolder(0, sTitle, flags, vRoot)
    If obj Is Nothing Then Exit Function
    Set obj = obj.Self
    If obj Is Nothing Then Exit Function
    GetFolder = CStr(obj.Path)
    Set obj = Nothing

End Function


Sub RunCopy(source, dest, cmd, switches)

    Dim cmdline, wsh

    On Error Resume Next
    Set wsh = WScript.CreateObject("WScript.Shell")
    cmdline = cmd & source & dest & switches

    wsh.Run cmdline, , vbTrue

    If Err Then Err.Clear
    On Error GoTo 0

End Sub


Function TargetName(fDest, fSource)

    Dim fso

    On Error Resume Next
    Set fso = CreateObject("Scripting.FileSystemObject")
    With fso
        TargetName = .BuildPath(fDest, .GetBaseName(fSource))
    End With
    Set fso = Nothing
    If Err Then Err.Clear
    On Error GoTo 0

End Function


